@@ -11,7 +11,7 @@ arch_get_kernel_flavour () {
 	    omap|mx5|vexpress)
 		echo "$SUBARCH armmp"
 		return 0 ;;
-	    generic)
+	    generic|efi)
 		case `arch_has_lpae` in
 		    y)
 			echo "armmp-lpae armmp"
@@ -54,17 +54,11 @@ arch_check_usable_kernel () {
 }
 
 arch_get_kernel () {
-	case "$KERNEL_MAJOR" in
-	    2.6|3.*)
-		imgbase="linux-image"
+	imgbase="linux-image"
 
-		set -- $1
-		while [ $# -ge 1 ]; do
-			echo "$imgbase-$1"
-			shift
-		done
-		;;
-	    *)	warning "Unsupported kernel major '$KERNEL_MAJOR'."
-		;;
-	esac
+	set -- $1
+	while [ $# -ge 1 ]; do
+		echo "$imgbase-$1"
+		shift
+	done
 }
