@@ -622,18 +622,18 @@ EOF
 			;;
 		esac
 		resume_devfs="$(get_resume_partition)" || resume_devfs=
-		if [ "$resume_devfs" ] && [ -e "$resume_devfs" ]; then
-			resume="$(mapdevfs "$resume_devfs")" || resume=
-		else
-			resume=
-		fi
-		if [ "$resume" ] && ! echo "$resume" | grep -q "^/dev/mapper/"; then
-			resume_uuid="$(block-attr --uuid "$resume" || true)"
-			if [ "$resume_uuid" ]; then
-				resume="UUID=$resume_uuid"
+		if [ "$resume_devfs" ] && [ -e "$resume_devfs" ] && \
+		   resume="$(mapdevfs "$resume_devfs")"; then
+			if ! echo "$resume" | grep -q "^/dev/mapper/"; then
+				resume_uuid="$(block-attr --uuid "$resume" || true)"
+				if [ "$resume_uuid" ]; then
+					resume="UUID=$resume_uuid"
+				fi
 			fi
+		else
+			resume=none
 		fi
-		if [ -n "$resumeconf" ] && [ "$resume" ]; then
+		if [ -n "$resumeconf" ]; then
 			if [ -f $resumeconf ] ; then
 				sed -e "s@^#* *RESUME=.*@RESUME=$resume@" < $resumeconf > $resumeconf.new &&
 					mv $resumeconf.new $resumeconf
@@ -660,10 +660,18 @@ EOF
 	# Advance progress bar to 30% of allocated space for install_kernel_linux
 	update_progress 30 100
 
+	# We really should install Recommends by default here (see #929667)
+	db_get base-installer/install-recommends
+	if [ "$RET" = true ]; then
+		KERNEL_INSTALL_OPTS=--with-recommends
+	else
+		KERNEL_INSTALL_OPTS=
+	fi
+
 	# Install the kernel
 	db_subst base-installer/section/install_kernel_package SUBST0 "$KERNEL"
 	db_progress INFO base-installer/section/install_kernel_package
-	log-output -t base-installer apt-install "$KERNEL" || kernel_install_failed=$?
+	log-output -t base-installer apt-install $KERNEL_INSTALL_OPTS "$KERNEL" || kernel_install_failed=$?
 
 	# Advance progress bar to 90% of allocated space for install_kernel_linux
 	update_progress 90 100
@@ -879,3 +887,14 @@ EOT
 cleanup () {
 	rm -f "$KERNEL_LIST" "$KERNEL_LIST.unfiltered"
 }
+
+is_ports_architecture() {
+	case "$1" in
+		alpha|hppa|hurd-i386|ia64|kfreebsd-amd64|kfreebsd-i386|m68k|powerpc|ppc64|riscv64|sh4|sparc64|x32)
+			return 0
+			;;
+		*)
+			return 1
+			;;
+	esac
+}
